@@ -49,7 +49,7 @@ class Base(Controller):
                 "help" : "IP to add to security group",
                 "action": "store"
             }),
-            (['-p','--proifle'],{
+            (['-p','--profile'],{
                 "help" : "Which AWS profile should boto3 use",
                 "action" : "store"
             })
@@ -58,9 +58,10 @@ class Base(Controller):
     def sg(self):
         from ..ext.aws_sg import get_sg, update_sg_to_ip
         profile = self.app.pargs.__dict__.get('profile') or self.app.pargs.__dict__.get('p') or 'default'
+        name = self.app.pargs.__dict__.get('name') or self.app.pargs.__dict__.get('n') or 'default'
 
         if self.app.pargs.action=='show':
-            pp(get_sg(self.app.pargs.name, profile))
+            pp(get_sg(name, profile))
 
         elif self.app.pargs.action=='update':
             update_sg_to_ip(sg_name=self.app.pargs.name, profile=profile)
