@@ -17,7 +17,7 @@ def execute(command: str, filt_cond: str, directory=''):
     target_files.swifter.apply(lambda x: target_fcn(x))
 
 
-def get_files_as_pd():
+def get_files_as_pd(directory):
     '''
     Gets all files from recursive directories and returns this as
     a `DataFrame`
